part of mdlcomponents;

/// directive for materialtextfield
@Directive(
	selector: '[floatinglabel]')
class FloatingLabel{}
/// directive for materialtextfield
@Directive(
	selector: '[type]')
class InputType{}
/// directive for materialtextfield
@Directive(
	selector: '[label]')
class InputLabel{}
/// directive for materialtextfield
@Directive(
	selector: '[value]')
class InputValue{}
/// directive for materialtextfield
@Directive(
	selector: '[pattern]')
class InputPattern{}
/// directive for materialtextfield
@Directive(
	selector: '[disabled]')
class InputDisabled{}
/// Example for floating label 
///<ngForm>
///<material-textfield label="Username or EMail" floatinglabel type="text" pattern="[0-9]" value="hello" #textfield></material-textfield>
///</ngForm>
/// #textfield label for 
/// @ViewChild('textfield')
///	MaterialTextField materialTextField;
/// materialTextField.label = "New label" & etc attribute set or get (floatinglabel,type,pattern,value,disabled)
///
@Component(
	selector: 'material-textfield',
	directives: const [COMMON_DIRECTIVES,InputType,InputLabel,InputPattern,InputDisabled,InputValue],
	templateUrl: 'src/components/MaterialTextField.html')

class MaterialTextField implements OnChanges{
	ApplicationRef _appRef;
	bool _disabled;
	bool _floatinglabel;
	String _label ='Username';
	String _id;
	String _pattern;
	String _inputtype;
	@Input()
	String _value;
	Map<String,bool> _textfieldClasses;
	Map<String,bool> _inputClasses;
	Map<String,bool> _labelClasses;

    MaterialTextField(@Optional() @Attribute('type') String inputtype,@Optional() @Attribute('floatinglabel') bool floatinglabel,@Optional() @Attribute('label') String label,@Optional() @Attribute('value') String value,@Optional() @Attribute('pattern') String pattern,@Optional() @Attribute('disabled') String disabled,ApplicationRef appRef){
     _appRef = appRef;
     if (inputtype != null && inputtype.isNotEmpty) {_inputtype = inputtype;}
     else {
		_inputtype = 'text';
     }
     if (floatinglabel != null && floatinglabel.isEmpty) { _floatinglabel = true;}
     if (label != null && label.isNotEmpty)  {_label = label;}
     if (value != null && value.isNotEmpty)  {_value = value;}
     if (pattern != null && pattern.isNotEmpty){_pattern = pattern;}
     if (disabled != null && disabled.isNotEmpty && disabled == 'true') { _disabled = true;}
    _textfieldClasses =  {'mdl-textfield':true,'mdl-js-textfield':true,'mdl-textfield--floating-label':_floatinglabel,'is-focused':(value != null && value.isNotEmpty)? true:false};
    _inputClasses = {'mdl-textfield__input':true};
    _labelClasses = {'mdl-textfield__label':true};
    Uuid uuid = new Uuid();
    _id = uuid.v1();
    }
	/// on focus
    void onfocus(){
    if (!_textfieldClasses['is-focused']){
		_textfieldClasses['is-focused'] = true;
		}
    }
    /// on blur
    void onblur(){
    _appRef.tick();
    _textfieldClasses['is-focused'] = (value != null && value.isNotEmpty)? true:false;
    }

    /// Disable button.
    void disable() {
        _disabled = true;
    }

    /// Enable button.
    void enable() {
        _disabled = false;
    }

	void ngOnChanges(Map<String, SimpleChange> changes) {
		 changes.forEach((String propName, SimpleChange change) {
		    if (change.currentValue != change.previousValue) {
		    if (propName == 'value') { _textfieldClasses['is-focused'] = ( _floatinglabel && change.currentValue != null && change.currentValue.isNotEmpty)? true:false;}
		    }
		      
		  });
		}

    
    void set enabled(final bool _enabled) => _enabled ? enable() : disable();

    Map<String,bool> get textfieldClasses => _textfieldClasses;
    
    Map<String,bool> get inputClasses => _inputClasses;
    
    Map<String,bool> get labelClasses => _labelClasses;
    
    bool get enabled => !_disabled;

    String get label => _label;
    
    String get value => _value;

    String get id => _id;

    String get inputtype => _inputtype;
    
    String get pattern => _pattern;

	bool get floatinglabel => _floatinglabel;

    void set label(final String value) {
        if(value != null) {
            _label = value;
        }
    }

    void set value(final String value) {
        if(value != null) {
            _value = value;
        }
    }


	void set id(bool value) { _id = value;}
	
	void set inputtype(bool value) { _inputtype = value;}

	void set pattern(bool value) { _pattern = value;}

	void set floatinglabel(bool value) { _floatinglabel = value;}


}


